@@ -159,6 +159,7 @@ class Calculation(InputTemplate):
         self._fix_lattice = False
         self._melting_cycle = True
         self._pair_style = None
+        self._pair_style_options = None
         self._pair_coeff = None
         self._potential_file = None
         self._fix_potential_path = True
@@ -187,6 +188,7 @@ class Calculation(InputTemplate):
         self.md.thermostat_damping = 0.1
         self.md.barostat_damping = 0.1
         self.md.cmdargs = None
+        self.md.init_commands = None
 
         self.nose_hoover = InputTemplate()
         self.nose_hoover.thermostat_damping = 0.1
@@ -209,7 +211,7 @@ class Calculation(InputTemplate):
         
         self.tolerance = InputTemplate()
         self.tolerance.lattice_constant = 0.0002
-        self.tolerance.spring_constant = 0.01
+        self.tolerance.spring_constant = 0.1
         self.tolerance.solid_fraction = 0.7
         self.tolerance.liquid_fraction = 0.05
         self.tolerance.pressure = 0.5
@@ -230,6 +232,9 @@ class Calculation(InputTemplate):
         data = "%s system with T=%s, P=%s in %s lattice for mode %s"%(self.to_string(self.reference_phase),
             self.to_string(self._temperature), self.to_string(self._pressure), self.to_string(self.lattice), self.to_string(self.mode)) 
         return data
+
+    def _repr_json_(self):
+        return self.to_dict()
     
     def to_string(self, val):
         if val is None:
@@ -435,8 +440,39 @@ class Calculation(InputTemplate):
     @pair_style.setter
     def pair_style(self, val):
         val = self.check_and_convert_to_list(val)
+        ps_lst = []
+        ps_options_lst = []
+        for ps in val:
+            ps_split = ps.split()
+            ps_lst.append(ps_split[0])
+            if len(ps) > 1:
+                ps_options_lst.append(" ".join(ps_split[1:]))
+            else:
+                ps_options_lst.append("")
+
         #val = self.fix_paths(val)
-        self._pair_style = val
+        self._pair_style = ps_lst
+
+        #only set if its None
+        if self.pair_style_options is None:
+            self.pair_style_options = ps_options_lst
+
+
+    @property
+    def pair_style_options(self):
+        return self._pair_style_options
+
+    @pair_style_options.setter
+    def pair_style_options(self, val):
+        val = self.check_and_convert_to_list(val)
+        self._pair_style_options = val
+
+    @property
+    def pair_style_with_options(self):
+        #ignore options if lengths do not match
+        if len(self.pair_style) != len(self.pair_style_options):
+            self.pair_style_options = [self.pair_style_options[0] for x in range(len(self.pair_style))]
+        return [" ".join([self.pair_style[i], self.pair_style_options[i]]) for i in range(len(self.pair_style))]
 
     @property
     def pair_coeff(self):
@@ -757,7 +793,7 @@ def read_inputfile(file):
             #create calculations
             for combo in combos:
                 calc = Calculation.generate(indata)
-                calc.add_from_dict(ci, keys=["mode", "pair_style", "pair_coeff", "repeat", "n_equilibration_steps",
+                calc.add_from_dict(ci, keys=["mode", "pair_style", "pair_coeff", "pair_style_options", "npt", "repeat", "n_equilibration_steps",
                                 "n_switching_steps", "n_print_steps", "n_iterations", "potential_file", "spring_constants",
                                 "melting_cycle", "equilibration_control", "folder_prefix", "temperature_high"])
                 calc.lattice = combo[0]["lattice"]
